/**
 * This file is part of Haketilo.
 *
 * Function: Storage through messages (server side).
 *
 * Copyright (C) 2021 Wojtek Kosior
 * Redistribution terms are gathered in the `copyright' file.
 */

/*
 * IMPORTS_START
 * IMPORT listen_for_connection
 * IMPORT get_storage
 * IMPORT list_prefixes
 * IMPORT CONNECTION_TYPE
 * IMPORTS_END
 */

var storage;

async function handle_remote_call(port, message)
{
    let [call_id, func, args] = message;

    try {
	let result = await Promise.resolve(storage[func](...args));
	port.postMessage({call_id, result});
    } catch (error) {
	error = error + '';
	port.postMessage({call_id, error});
    }
}

function remove_storage_listener(cb)
{
    storage.remove_change_listener(cb);
}

function new_connection(port)
{
    console.log("new remote storage connection!");

    const message = {};
    for (const prefix of list_prefixes)
	message[prefix] = storage.get_all(prefix);

    port.postMessage(message);

    let handle_change = change => port.postMessage(change);

    storage.add_change_listener(handle_change);

    port.onMessage.addListener(m => handle_remote_call(port, m));
    port.onDisconnect.addListener(() =>
				  remove_storage_listener(handle_change));
}

async function start_storage_server()
{
    storage = await get_storage();

    listen_for_connection(CONNECTION_TYPE.REMOTE_STORAGE, new_connection);
}

/*
 * EXPORTS_START
 * EXPORT start_storage_server
 * EXPORTS_END
 */
