/**
 * This file is part of Haketilo.
 *
 * Function: Operations on DOM elements.
 *
 * Copyright (C) 2021 Wojtek Kosior
 * Redistribution terms are gathered in the `copyright' file.
 */

function by_id(id)
{
    return document.getElementById(id);
}

const known_templates = new Map();

function get_template(template_id)
{
    let template = known_templates.get(template_id) || null;
    if (template)
	return template;

    for (const template_node of document.getElementsByTagName("TEMPLATE")) {
	template = template_node.content.getElementById(template_id);
	if (template)
	    break;
    }

    known_templates.set(template_id, template);
    return template;
}

function clone_template(template_id)
{
    const clone = get_template(template_id).cloneNode(true);
    const result_object = {};
    const to_process = [clone];

    while (to_process.length > 0) {
	const element = to_process.pop();
	const template_key = element.getAttribute("data-template");

	if (template_key)
	    result_object[template_key] = element;

	element.removeAttribute("id");
	element.removeAttribute("data-template");

	for (const child of element.children)
	    to_process.push(child);
    }

    return result_object;
}

/*
 * EXPORTS_START
 * EXPORT by_id
 * EXPORT get_template
 * EXPORT clone_template
 * EXPORTS_END
 */
